@@ -1,29 +1,13 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2003,2004 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2009 Sebastian Sauer <sebsauer@kdab.net>
-  Copyright (c) 2010-2020 Laurent Montel <montel@kde.org>
-  Copyright (C) 2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2003, 2004 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2009 Sebastian Sauer <sebsauer@kdab.net>
+  SPDX-FileCopyrightText: 2010-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "akonadicollectionview.h"
@@ -32,7 +16,6 @@
 #include "prefs/koprefs.h"
 #include "koglobals.h"
 #include "manageshowcollectionproperties.h"
-#include "views/collectionview/reparentingmodel.h"
 #include "views/collectionview/calendardelegate.h"
 #include "views/collectionview/quickview.h"
 
@@ -127,7 +110,7 @@ private Q_SLOTS:
     }
 
 private:
-    QAbstractItemModel *mCheckableProxy = nullptr;
+    QAbstractItemModel *const mCheckableProxy;
 };
 
 /**
@@ -342,7 +325,7 @@ protected:
 
         const Akonadi::Collection &col
             = sourceIndex.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
-        const Akonadi::CollectionIdentificationAttribute *attr
+        const auto *attr
             = col.attribute<Akonadi::CollectionIdentificationAttribute>();
 
         //We filter the user folders because we insert person nodes for user folders.
@@ -424,10 +407,10 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
 {
     mManagerShowCollectionProperties = new ManageShowCollectionProperties(this, this);
 
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
-    topLayout->setContentsMargins(0, 0, 0, 0);
+    auto *topLayout = new QVBoxLayout(this);
+    topLayout->setContentsMargins({});
 
-    QLineEdit *searchCol = new QLineEdit(this);
+    auto *searchCol = new QLineEdit(this);
     searchCol->setToolTip(i18nc("@info:tooltip", "Set search keyword"));
     searchCol->setWhatsThis(
         i18nc("@info:whatsthis", "Lets you search for a keyword in your calendars"));
@@ -436,16 +419,16 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
                                         "textbox, verb to search", "Search..."));
     topLayout->addWidget(searchCol);
 
-    ColorProxyModel *colorProxy = new ColorProxyModel(this);
+    auto *colorProxy = new ColorProxyModel(this);
     colorProxy->setObjectName(QStringLiteral("Show calendar colors"));
     colorProxy->setDynamicSortFilter(true);
     mBaseModel = colorProxy;
 
-    CalendarDelegateModel *calendarDelegateModel = new CalendarDelegateModel(this);
+    auto *calendarDelegateModel = new CalendarDelegateModel(this);
     calendarDelegateModel->setSourceModel(mBaseModel);
 
     //Hide collections that are not required
-    CollectionFilter *collectionFilter = new CollectionFilter(this);
+    auto *collectionFilter = new CollectionFilter(this);
     collectionFilter->setSourceModel(calendarDelegateModel);
 
     mCollectionView = new Akonadi::EntityTreeView(this);
@@ -453,7 +436,7 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
     mCollectionView->setRootIsDecorated(true);
     // mCollectionView->setSorting( true );
     {
-        StyledCalendarDelegate *delegate = new StyledCalendarDelegate(mCollectionView);
+        auto *delegate = new StyledCalendarDelegate(mCollectionView);
         connect(delegate, &StyledCalendarDelegate::action, this, &AkonadiCollectionView::onAction);
         mCollectionView->setItemDelegate(delegate);
     }
@@ -465,11 +448,11 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
         = new NewNodeExpander(mCollectionView, false, QStringLiteral("CollectionTreeView"));
 
     //Filter tree view.
-    ReparentingModel *searchProxy = new ReparentingModel(this);
+    auto *searchProxy = new ReparentingModel(this);
     searchProxy->setSourceModel(collectionFilter);
     searchProxy->setObjectName(QStringLiteral("searchProxy"));
 
-    QSortFilterProxyModel *filterTreeViewModel = new QSortFilterProxyModel(this);
+    auto *filterTreeViewModel = new QSortFilterProxyModel(this);
     filterTreeViewModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
     filterTreeViewModel->setRecursiveFilteringEnabled(true);
     filterTreeViewModel->setDynamicSortFilter(true);
@@ -477,11 +460,11 @@ AkonadiCollectionView::AkonadiCollectionView(CalendarView *view, bool hasContext
     connect(searchCol, &QLineEdit::textChanged, filterTreeViewModel,
             &QSortFilterProxyModel::setFilterWildcard);
 
-    Akonadi::EntityTreeView *mSearchView = new Akonadi::EntityTreeView(this);
+    auto *mSearchView = new Akonadi::EntityTreeView(this);
     mSearchView->header()->hide();
     mSearchView->setRootIsDecorated(true);
     {
-        StyledCalendarDelegate *delegate = new StyledCalendarDelegate(mCollectionView);
+        auto *delegate = new StyledCalendarDelegate(mCollectionView);
         connect(delegate, &StyledCalendarDelegate::action, this, &AkonadiCollectionView::onAction);
         mSearchView->setItemDelegate(delegate);
     }
@@ -615,7 +598,7 @@ void AkonadiCollectionView::slotServerSideSubscription()
     if (!collection.isValid()) {
         return;
     }
-    PimCommon::ManageServerSideSubscriptionJob *job
+    auto *job
         = new PimCommon::ManageServerSideSubscriptionJob(this);
     job->setCurrentCollection(collection);
     job->setParentWidget(this);
@@ -755,7 +738,7 @@ void AkonadiCollectionView::newCalendar()
         mNotSendAddRemoveSignal = true;
         const Akonadi::AgentType agentType = dlg->agentType();
         if (agentType.isValid()) {
-            Akonadi::AgentInstanceCreateJob *job = new Akonadi::AgentInstanceCreateJob(agentType,
+            auto *job = new Akonadi::AgentInstanceCreateJob(agentType,
                                                                                        this);
             job->configure(this);
             connect(job, &Akonadi::AgentInstanceCreateJob::result, this,
@@ -768,7 +751,7 @@ void AkonadiCollectionView::newCalendar()
 
 void AkonadiCollectionView::newCalendarDone(KJob *job)
 {
-    Akonadi::AgentInstanceCreateJob *createjob
+    auto *createjob
         = static_cast<Akonadi::AgentInstanceCreateJob *>(job);
     if (createjob->error()) {
         //TODO(AKONADI_PORT)
@@ -807,7 +790,7 @@ void AkonadiCollectionView::deleteCalendar()
 
         if (!isTopLevel) {
             // deletes contents
-            Akonadi::CollectionDeleteJob *job = new Akonadi::CollectionDeleteJob(collection, this);
+            auto *job = new Akonadi::CollectionDeleteJob(collection, this);
             connect(job, &Akonadi::AgentInstanceCreateJob::result, this,
                     &AkonadiCollectionView::deleteCalendarDone);
         } else {
@@ -823,7 +806,7 @@ void AkonadiCollectionView::deleteCalendar()
 
 void AkonadiCollectionView::deleteCalendarDone(KJob *job)
 {
-    Akonadi::CollectionDeleteJob *deletejob = static_cast<Akonadi::CollectionDeleteJob *>(job);
+    auto *deletejob = static_cast<Akonadi::CollectionDeleteJob *>(job);
     if (deletejob->error()) {
         qCWarning(KORGANIZER_LOG) << "Delete calendar failed:" << deletejob->errorString();
         mNotSendAddRemoveSignal = false;
@@ -905,9 +888,9 @@ bool AkonadiCollectionView::isChecked(const Akonadi::Collection &collection) con
 
 Akonadi::EntityTreeModel *AkonadiCollectionView::entityTreeModel() const
 {
-    QAbstractProxyModel *proxy = qobject_cast<QAbstractProxyModel *>(mCollectionView->model());
+    auto *proxy = qobject_cast<QAbstractProxyModel *>(mCollectionView->model());
     while (proxy) {
-        Akonadi::EntityTreeModel *etm = qobject_cast<Akonadi::EntityTreeModel *>(
+        auto *etm = qobject_cast<Akonadi::EntityTreeModel *>(
             proxy->sourceModel());
         if (etm) {
             return etm;
@@ -921,7 +904,7 @@ Akonadi::EntityTreeModel *AkonadiCollectionView::entityTreeModel() const
 
 void AkonadiCollectionView::onAction(const QModelIndex &index, int a)
 {
-    const StyledCalendarDelegate::Action action = static_cast<StyledCalendarDelegate::Action>(a);
+    const auto action = static_cast<StyledCalendarDelegate::Action>(a);
     switch (action) {
     case StyledCalendarDelegate::Quickview:
     {
