@@ -1,32 +1,16 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 1997, 1998, 1999 Preston Brown <preston.brown@yale.edu>
-  Fester Zigterman <F.J.F.ZigtermanRustenburg@student.utwente.nl>
-  Ian Dawes <iadawes@globalserve.net>
-  Laszlo Boloni <boloni@cs.purdue.edu>
+  SPDX-FileCopyrightText: 1997, 1998, 1999 Preston Brown <preston.brown@yale.edu>
+  SPDX-FileCopyrightText: Fester Zigterman <F.J.F.ZigtermanRustenburg@student.utwente.nl>
+  SPDX-FileCopyrightText: Ian Dawes <iadawes@globalserve.net>
+  SPDX-FileCopyrightText: Laszlo Boloni <boloni@cs.purdue.edu>
 
-  Copyright (C) 2000-2004 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2000-2004 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "calendarview.h"
@@ -49,7 +33,6 @@
 #include "widgets/navigatorbar.h"
 #include "pimmessagebox.h"
 
-
 #include <AkonadiCore/AttributeFactory>
 #include <AkonadiCore/CollectionIdentificationAttribute>
 
@@ -101,8 +84,6 @@
 
 CalendarView::CalendarView(QWidget *parent)
     : CalendarViewBase(parent)
-    , mCheckableProxyModel(nullptr)
-    , mETMCollectionView(nullptr)
     , mSearchCollectionHelper(this)
 {
     Akonadi::ControlGui::widgetNeedsAkonadi(this);
@@ -153,8 +134,8 @@ CalendarView::CalendarView(QWidget *parent)
     mDateNavigator = new DateNavigator(this);
     mDateChecker = new DateChecker(this);
 
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
-    topLayout->setContentsMargins(0, 0, 0, 0);
+    auto *topLayout = new QVBoxLayout(this);
+    topLayout->setContentsMargins({});
 
     // create the main layout frames.
     mPanner = new QSplitter(Qt::Horizontal, this);
@@ -175,16 +156,16 @@ CalendarView::CalendarView(QWidget *parent)
     mTodoList->setObjectName(QStringLiteral("todolist"));
 
     mEventViewerBox = new QWidget(mLeftSplitter);
-    QVBoxLayout *mEventViewerBoxVBoxLayout = new QVBoxLayout(mEventViewerBox);
-    mEventViewerBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
-    mEventViewerBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
+    auto *mEventViewerBoxVBoxLayout = new QVBoxLayout(mEventViewerBox);
+    mEventViewerBoxVBoxLayout->setContentsMargins({});
+    mEventViewerBoxVBoxLayout->setContentsMargins({});
     mEventViewer = new CalendarSupport::IncidenceViewer(mCalendar.data(), mEventViewerBox);
     mEventViewer->setObjectName(QStringLiteral("EventViewer"));
     mEventViewerBoxVBoxLayout->addWidget(mEventViewer);
 
     QWidget *rightBox = new QWidget(mPanner);
-    QVBoxLayout *rightBoxVBoxLayout = new QVBoxLayout(rightBox);
-    rightBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
+    auto *rightBoxVBoxLayout = new QVBoxLayout(rightBox);
+    rightBoxVBoxLayout->setContentsMargins({});
     mNavigatorBar = new NavigatorBar(rightBox);
     rightBoxVBoxLayout->addWidget(mNavigatorBar);
     mRightFrame = new QStackedWidget(rightBox);
@@ -258,7 +239,7 @@ CalendarView::CalendarView(QWidget *parent)
             mDateNavigator, &DateNavigator::selectNext);
 
     connect(mDateNavigatorContainer, &DateNavigatorContainer::datesSelected,
-            mDateNavigator, QOverload<const KCalendarCore::DateList &, const QDate &>::of(&DateNavigator::selectDates));
+            mDateNavigator, QOverload<const KCalendarCore::DateList &, QDate >::of(&DateNavigator::selectDates));
 
     connect(mViewManager, &KOViewManager::datesSelected,
             mDateNavigator, [this](const KCalendarCore::DateList &dates) {
@@ -380,7 +361,7 @@ QDate CalendarView::activeIncidenceDate()
         }
     }
 
-    return QDate();
+    return {};
 }
 
 QDate CalendarView::startDate()
@@ -502,7 +483,7 @@ void CalendarView::readFilterSettings(KConfig *config)
     QStringList::ConstIterator it = filterList.constBegin();
     QStringList::ConstIterator end = filterList.constEnd();
     while (it != end) {
-        KCalendarCore::CalFilter *filter = new KCalendarCore::CalFilter(*it);
+        auto *filter = new KCalendarCore::CalFilter(*it);
         KConfigGroup filterConfig(config, QStringLiteral("Filter_") + (*it));
         filter->setCriteria(filterConfig.readEntry("Criteria", 0));
         filter->setCategoryList(filterConfig.readEntry("CategoryList", QStringList()));
@@ -552,12 +533,12 @@ void CalendarView::writeFilterSettings(KConfig *config)
     }
 }
 
-void CalendarView::goDate(const QDate &date)
+void CalendarView::goDate(QDate date)
 {
     mDateNavigator->selectDate(date);
 }
 
-void CalendarView::showDate(const QDate &date)
+void CalendarView::showDate(QDate date)
 {
     int dateCount = mDateNavigator->datesCount();
     if (dateCount == 7) {
@@ -1175,7 +1156,7 @@ void CalendarView::newJournal(const Akonadi::Collection &collection)
     dialog->load(item);
 }
 
-void CalendarView::newJournal(const QString &text, const QDate &date)
+void CalendarView::newJournal(const QString &text, QDate date)
 {
     IncidenceEditorNG::IncidenceDefaults defaults
         = IncidenceEditorNG::IncidenceDefaults::minimalIncidenceDefaults();
@@ -1586,7 +1567,7 @@ void CalendarView::moveIncidenceToResource(const Akonadi::Item &item, const Akon
 #endif
 }
 
-void CalendarView::dissociateOccurrences(const Akonadi::Item &item, const QDate &date)
+void CalendarView::dissociateOccurrences(const Akonadi::Item &item, QDate date)
 {
     const KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
 
@@ -1843,7 +1824,7 @@ void CalendarView::exportICalendar()
                 return;
             }
         }
-        KCalendarCore::ICalFormat *format = new KCalendarCore::ICalFormat;
+        auto *format = new KCalendarCore::ICalFormat;
 
         KCalendarCore::FileStorage storage(mCalendar, filename, format);
         if (!storage.save()) {
@@ -2187,7 +2168,7 @@ void CalendarView::pasteIncidence()
 
 void CalendarView::showIncidence(const Akonadi::Item &item)
 {
-    KOEventViewerDialog *eventViewer = new KOEventViewerDialog(mCalendar.data(), this);
+    auto *eventViewer = new KOEventViewerDialog(mCalendar.data(), this);
     eventViewer->setIncidence(item, QDate());
     // Disable the Edit button for read-only Incidences.
     if (!mCalendar->hasRight(item, Akonadi::Collection::CanChangeItem)) {
@@ -2534,7 +2515,7 @@ void CalendarView::addIncidenceOn(const Akonadi::Item &itemadd, const QDate &dt)
     mChanger->createIncidence(incidence, Akonadi::Collection(), this);
 }
 
-void CalendarView::moveIncidenceTo(const Akonadi::Item &itemmove, const QDate &dt)
+void CalendarView::moveIncidenceTo(const Akonadi::Item &itemmove, QDate dt)
 {
     if (!CalendarSupport::hasIncidence(itemmove)) {
         KMessageBox::sorry(
